@@ -7,9 +7,10 @@
 #define exact 1
 
 double kww(int n, double p, double a);
-double tl_factor(int n, double p, double a, int m);
+double tl_factor (int n, double p, double a, int m);
 
-void tol_lim_fac(int *n, double *p, double *a, int *mtype, int *m, double *tlf )
+void tol_lim_fac
+( int *n, double *p, double *a, int *mtype, int *m, double *tlf )
 {
   if (*mtype==WW) *tlf = kww(*n,*p,*a);
   else *tlf = tl_factor(*n,*p,*a,*m);        
